@@ -1,7 +1,7 @@
-#define QT_FEATURE_ffmpeg 1
-
 #define QT_FEATURE_pipewire -1
 
+#define QT_FEATURE_pipewire_screencapture -1
+
 #define QT_FEATURE_alsa -1
 
 #define QT_FEATURE_avfoundation 1
@@ -10,8 +10,6 @@
 
 #define QT_FEATURE_videotoolbox 1
 
-#define QT_FEATURE_evr -1
-
 #define QT_FEATURE_gstreamer -1
 
 #define QT_FEATURE_gstreamer_photography -1
@@ -34,17 +32,23 @@
 
 #define QT_FEATURE_mmrenderer -1
 
+#define QT_FEATURE_native_android_backend -1
+
+#define QT_FEATURE_native_windows_backend -1
+
 #define QT_FEATURE_pulseaudio 1
 
-#define QT_FEATURE_wmsdk -1
-
-#define QT_FEATURE_opensles -1
+#define QT_FEATURE_aaudio -1
 
 #define QT_FEATURE_wasm -1
 
-#define QT_FEATURE_wmf -1
+#define QT_FEATURE_wasapi -1
 
 #define QT_FEATURE_spatialaudio 1
 
 #define QT_FEATURE_spatialaudio_quick3d 1
 
+#define QT_FEATURE_ffmpeg 1
+
+#define QT_FEATURE_ffmpeg_stubs -1
+
